@@ -37,6 +37,9 @@ Debug模式开启，使用装饰器，成功增加返回输入参数，失败增
 v1.0.3
 1、修改书写错误worning改成warning，以前写法仍旧可用
 2、修改书写错误erro改成error，方法名替换
+
+v1.0.4
+1、修复使用装饰器不能进行值返回的bug
 '''
 
 import time
@@ -201,13 +204,14 @@ def logger(success='Success', fail='Fail'):
             __lcok = threading.RLock()
             __lcok.acquire()
             try:
-                func(*args, **kwargs)
+                res = func(*args, **kwargs)
                 argument = get_args(*args, **kwargs)
                 now_time = time.strftime('%Y-%m-%d %H:%M:%S')
                 def_name = func.__name__
                 line = sys._getframe(1).f_lineno
                 file_path = sys._getframe(1).f_code.co_filename
                 __Getlog().success(now_time, file_path, def_name, line, success, argument)
+                return res
             except Exception as e:
                 now_time = time.strftime('%Y-%m-%d %H:%M:%S')
                 def_name = func.__name__
